==> minitube-src-0.6.1.tar.gz: minitube/locale/uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk_UA">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>За межами браузера також є життя!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Версія %1</translation>
    </message>
    <message>
        <source>This is a &quot;Technology Preview&quot; release, do not expect it to be perfect.</source>
        <translation>Це технологічний попередній випуск програми, не очікуйте від нього досконалості.</translation>
    </message>
    <message>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>Повідомляйте про несправності та висилайте ваші ідеї на %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 є Вільним Програмним Забезпеченням але на його розробку було затрачено коштовний час.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate via PayPal&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Будь ласка  &lt;a href=&apos;%1&apos;&gt;скористайтесь PayPal&lt;/a&gt; щоб підтримати подальший розвиток %2.</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Розробник піктограм %1.</translation>
    </message>
    <message>
        <source>Translated by %1</source>
        <translation>Переклад %1</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Випущено під  &lt;a href=&apos;%1&apos;&gt;Загальною громадською ліцензією GNU&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>Пове&amp;рнутися</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Про програму</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Все що ви завжди хотіли знати про %1 але не наважувались запитати</translation>
    </message>
    <message>
        <source>Compact mode contributed by %1.</source>
        <translation>Розробка компактного режиму %1.</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Очистити</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <source>Searching...</source>
        <translation>Шукаю...</translation>
    </message>
    <message>
        <source>Show %1 More</source>
        <translation>Наступні %1 </translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Нічого не знайдено </translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Більше немає</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Помилка</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Назад</translation>
    </message>
    <message>
        <source>Alt+Left</source>
        <translation>Alt+Вліво</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation>Повернутися до попереднього режиму</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Зупинити</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Зупинити відтворення і перейти до вікна пошуку</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>П&amp;ропустити</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Перейти до наступного відео</translation>
    </message>
    <message>
        <source>Ctrl+Right</source>
        <translation>Ctrl+Вправо</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Призупинити</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Призупинити відтворення</translation>
    </message>
    <message>
        <source>Space</source>
        <translation>Клавіша пробілу</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>Н&amp;а весь экран</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Перехід в повноекранний режим</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation>Alt+Enter</translation>
    </message>
    <message>
        <source>&amp;YouTube</source>
        <translation>&amp;YouTube</translation>
    </message>
    <message>
        <source>Open the YouTube video page</source>
        <translation>Відкрити сторінку YouTube</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Видалити</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Видалити обрані відео з переліку композицій</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Зсув в&amp;гору</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Зсунути обране відео на позицію вгору в переліку композицій</translation>
    </message>
    <message>
        <source>Ctrl+Up</source>
        <translation>Ctrl+Вгору</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Зсув вни&amp;з</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Зсунути обране відео на позицію вниз в переліку композицій</translation>
    </message>
    <message>
        <source>Ctrl+Down</source>
        <translation>Ctrl+Вниз</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Ви&amp;хід</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Хай щастить</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>Домашн&amp;я сторінка програми</translation>
    </message>
    <message>
        <source>Minitube on the Web</source>
        <translation>Minitube в мережі</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 в мережі</translation>
    </message>
    <message>
        <source>&amp;Donate via PayPal</source>
        <translation>Підтрима&amp;йте проект через PayPal</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Будь ласка підтримайте подальший розвиток %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Про програму</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Інформація про %1</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation>Пош&amp;ук</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Програма</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>Перелік &amp;композицій</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>В&amp;ідео</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Допомога</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Відкриваю %1</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>Відтворюв&amp;ати</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Продовжити відтворення</translation>
    </message>
    <message>
        <source>Exit &amp;Full Screen</source>
        <translation>Вийти з повноекр&amp;анного режиму</translation>
    </message>
    <message>
        <source>&amp;Compact mode</source>
        <translation>&amp;Компактний режим</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Приховати перелік композицій та панель інструментів</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Невиправна помилка: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Помилка: %1</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Гучність %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Гучність приглушено</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Гучність відновлено</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Пошук</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Приглушити гучність </translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>%1 щоб приглушити гучність, %2 щоб відновити </translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Час до завершення: %1</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Most relevant</source>
        <translation>Подібні</translation>
    </message>
    <message>
        <source>Most recent</source>
        <translation>Недавні</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>Популярні</translation>
    </message>
    <message>
        <source>You&apos;re watching &quot;%1&quot;</source>
        <translation>Ви дивитесь &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <source>Network error: %1</source>
        <translation>Помилка мережі %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <source>%1 views</source>
        <translation>переглядів %1</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Пошук</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Вітаємо в &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>Enter a keyword to start watching videos.</source>
        <translation>Введіть терміни для пошуку відео.</translation>
    </message>
    <message>
        <source>Watch</source>
        <translation>Перегляд</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Недавній пошук</translation>
    </message>
    <message>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>Наявна нова версія %1. Будь ласка &lt;a href=&apos;%2&apos;&gt; обновіть програму до версії %3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Влаштовуйтеся зручніше</translation>
    </message>
</context>
<context>
    <name>SettingsView</name>
    <message>
        <source>Preferences</source>
        <translation>Налаштування</translation>
    </message>
    <message>
        <source>&amp;Video options</source>
        <translation>Відео &amp;можливості</translation>
    </message>
    <message>
        <source>Use high quality video when available</source>
        <translation>Відтворювати відео високої якості при наявності</translation>
    </message>
    <message>
        <source>&amp;Saved recent keywords</source>
        <translation>&amp;Збережені недавні терміни пошуку</translation>
    </message>
    <message>
        <source>&amp;Clear recent keywords</source>
        <translation>Очистити недавн&amp;і терміни пошуку</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>За&amp;крити</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <source>Network error: %1 for %2</source>
        <translation>Помилка мережі: %1 для %2</translation>
    </message>
</context>
</TS>

==> minitube-src-0.8.tar.gz: minitube/locale/uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk_UA">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>За межами браузера також є життя!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Версія %1</translation>
    </message>
    <message>
        <source>This is a &quot;Technology Preview&quot; release, do not expect it to be perfect.</source>
        <translation>Це технологічний попередній випуск програми, не очікуйте від нього досконалості.</translation>
    </message>
    <message>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>Повідомляйте про несправності та висилайте ваші ідеї на %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 є Вільним Програмним Забезпеченням але на його розробку було затрачено коштовний час.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate via PayPal&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Будь ласка  &lt;a href=&apos;%1&apos;&gt;скористайтесь PayPal&lt;/a&gt; щоб підтримати подальший розвиток %2.</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Розробник піктограм %1.</translation>
    </message>
    <message>
        <source>Translated by %1</source>
        <translation>Переклад %1</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Випущено під  &lt;a href=&apos;%1&apos;&gt;Загальною громадською ліцензією GNU&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>Пове&amp;рнутися</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Про програму</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Все що ви завжди хотіли знати про %1 але не наважувались запитати</translation>
    </message>
    <message>
        <source>Compact mode contributed by %1.</source>
        <translation>Розробка компактного режиму %1.</translation>
    </message>
    <message>
        <source>HTTP proxy support contributed by %1.</source>
        <translation>Реалізація підтримки HTTP проксі %1.</translation>
    </message>
    <message>
        <source>Windows version built by %1</source>
        <translation>Версія для Windows %1</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Очистити</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <source>Searching...</source>
        <translation>Шукаю...</translation>
    </message>
    <message>
        <source>Show %1 More</source>
        <translation>Наступні %1 </translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Нічого не знайдено </translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Більше немає</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Помилка</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Назад</translation>
    </message>
    <message>
        <source>Alt+Left</source>
        <translation type="obsolete">Alt+Вліво</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation>Повернутися до попереднього режиму</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Зупинити</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Зупинити відтворення і перейти до вікна пошуку</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation type="obsolete">Esc</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>П&amp;ропустити</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Перейти до наступного відео</translation>
    </message>
    <message>
        <source>Ctrl+Right</source>
        <translation type="obsolete">Ctrl+Вправо</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Призупинити</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Призупинити відтворення</translation>
    </message>
    <message>
        <source>Space</source>
        <translation type="obsolete">Клавіша пробілу</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>Н&amp;а весь экран</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Перехід в повноекранний режим</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation type="obsolete">Alt+Enter</translation>
    </message>
    <message>
        <source>&amp;YouTube</source>
        <translation>&amp;YouTube</translation>
    </message>
    <message>
        <source>Open the YouTube video page</source>
        <translation>Відкрити сторінку YouTube</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation type="obsolete">Ctrl+Y</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Видалити</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Видалити обрані відео з переліку композицій</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Зсув в&amp;гору</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Зсунути обране відео на позицію вгору в переліку композицій</translation>
    </message>
    <message>
        <source>Ctrl+Up</source>
        <translation type="obsolete">Ctrl+Вгору</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Зсув вни&amp;з</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Зсунути обране відео на позицію вниз в переліку композицій</translation>
    </message>
    <message>
        <source>Ctrl+Down</source>
        <translation type="obsolete">Ctrl+Вниз</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Ви&amp;хід</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Хай щастить</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>Домашн&amp;я сторінка програми</translation>
    </message>
    <message>
        <source>Minitube on the Web</source>
        <translation type="obsolete">Minitube в мережі</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 в мережі</translation>
    </message>
    <message>
        <source>&amp;Donate via PayPal</source>
        <translation>Підтрима&amp;йте проект через PayPal</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Будь ласка підтримайте подальший розвиток %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Про програму</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Інформація про %1</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation type="obsolete">Пош&amp;ук</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation type="obsolete">&amp;Програма</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>Перелік &amp;композицій</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>В&amp;ідео</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Допомога</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Відкриваю %1</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>Відтворюв&amp;ати</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Продовжити відтворення</translation>
    </message>
    <message>
        <source>Exit &amp;Full Screen</source>
        <translation>Вийти з повноекр&amp;анного режиму</translation>
    </message>
    <message>
        <source>&amp;Compact mode</source>
        <translation>&amp;Компактний режим</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Приховати перелік композицій та панель інструментів</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Невиправна помилка: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Помилка: %1</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Гучність %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Гучність приглушено</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Гучність відновлено</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Пошук</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Приглушити гучність </translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>%1 щоб приглушити гучність, %2 щоб відновити </translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Час до завершення: %1</translation>
    </message>
    <message>
        <source>High Definition video is enabled</source>
        <translation>Відео високої чіткості активоване</translation>
    </message>
    <message>
        <source>High Definition video is not enabled</source>
        <translation>Відео високої чіткості не активоване</translation>
    </message>
    <message>
        <source>The current video is in High Definition</source>
        <translation>Відео в режимі високої чіткості</translation>
    </message>
    <message>
        <source>The current video is not in High Definition</source>
        <translation>ВІдео не в режимі високої чіткості</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Most relevant</source>
        <translation>Подібні</translation>
    </message>
    <message>
        <source>Most recent</source>
        <translation>Недавні</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>Популярні</translation>
    </message>
    <message>
        <source>You&apos;re watching &quot;%1&quot;</source>
        <translation>Ви дивитесь &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <source>Network error: %1</source>
        <translation>Помилка мережі %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <source>%1 views</source>
        <translation>переглядів %1</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Пошук</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Вітаємо в &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>Enter a keyword to start watching videos.</source>
        <translation>Введіть терміни для пошуку відео.</translation>
    </message>
    <message>
        <source>Watch</source>
        <translation>Перегляд</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Недавній пошук</translation>
    </message>
    <message>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>Наявна нова версія %1. Будь ласка &lt;a href=&apos;%2&apos;&gt; обновіть програму до версії %3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Влаштовуйтеся зручніше</translation>
    </message>
</context>
<context>
    <name>SettingsView</name>
    <message>
        <source>Preferences</source>
        <translation>Налаштування</translation>
    </message>
    <message>
        <source>&amp;Video options</source>
        <translation type="obsolete">Відео &amp;можливості</translation>
    </message>
    <message>
        <source>Use high quality video when available</source>
        <translation type="obsolete">Відтворювати відео високої якості при наявності</translation>
    </message>
    <message>
        <source>&amp;Saved recent keywords</source>
        <translation type="obsolete">&amp;Збережені недавні терміни пошуку</translation>
    </message>
    <message>
        <source>&amp;Clear recent keywords</source>
        <translation type="obsolete">Очистити недавн&amp;і терміни пошуку</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="obsolete">За&amp;крити</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <source>Network error: %1 for %2</source>
        <translation>Помилка мережі: %1 для %2</translation>
    </message>
</context>
</TS>
